  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

Table: Demonstration of a simple table. {#tbl:demo}

Table @tbl:demo is from the Pandoc User's Guide.  We can also have unreferenceable numbered tables:

A B
- -
0 1

Table: Even simpler. {#tbl:}
